@@ -59,87 +59,37 @@ class CGJobMgr extends CGExtensions
     $this->SetParameterType('jobid',CLEAN_INT);
     $this->RestrictUnknownParams();
     $this->RegisterRoute('/'.$this->GetName().'\/process$/',
-			 array('action'=>'process',
-			       'showtemplate'=>'false'));
-  }
-
-  function GetName() {
-    return get_class($this);
-  }
-
-  function GetFriendlyName() {
-    return $this->Lang('friendlyname');
-  }
-  
-  function GetVersion() {
-    return '1.2.11';
-  }
-
-  function GetDependencies() {
-    return array('CGExtensions'=>'1.30');
-  }
-
-  function MinimumCMSVersion() {
-    return '1.11.1';
+			 array('action'=>'process','showtemplate'=>'false'));
   }
 
+  function GetName() { return get_class($this); }
+  function GetFriendlyName() { return $this->Lang('friendlyname'); }
+  function GetVersion() { return '1.2.14'; }
+  function GetDependencies() { return array('CGExtensions'=>'1.31'); }
+  function MinimumCMSVersion() { return '1.11.3'; }
   public function GetAdminSection() { return 'siteadmin'; }
-
-  function LazyLoadAdmin() {
-    return TRUE;
-  }
-
-  function GetHelp() {
-    return @file_get_contents(dirname(__FILE__).'/help.inc');
-  }
-  
-  function GetAuthor() {
-    return 'calguy1000';
-  }
-  
-  function GetAuthorEmail() {
-    return 'calguy1000@gmail.com';
-  }
-  
-  function GetChangeLog() {
-    return @file_get_contents(dirname(__FILE__).'/changelog.html.inc');
-  }
-
-  function IsPluginModule() {
-    return true;
-  }
-
-  function GetAdminDescription() {
-    return $this->Lang('moddescription');
-  }
-  
-  function HasAdmin() {
-    return true;
-  }
+  function LazyLoadAdmin() { return TRUE; }
+  function GetHelp() { return @file_get_contents(dirname(__FILE__).'/help.inc'); }
+  function GetAuthor() { return 'calguy1000'; }
+  function GetAuthorEmail() { return 'calguy1000@gmail.com'; }
+  function IsPluginModule() { return true; }
+  function GetAdminDescription() { return $this->Lang('moddescription'); }
+  function HasAdmin() { return true; }
+  function GetChangeLog() { return @file_get_contents(dirname(__FILE__).'/changelog.html.inc'); }
+  function InstallPostMessage() { return $this->Lang('postinstall'); }
+  function UninstallPostMessage() { return $this->Lang('postuninstall'); }
+  function GetEventHelp( $eventname ) { return $this->Lang('help_event_'.$eventname); }
+  function AllowAutoInstall() { return FALSE; }
+  function AllowAutoUpgrade() { return FALSE; }
   
   function VisibleToAdminUser() {
     return $this->CheckPermission('Manage Jobs') ||
       $this->CheckPermission('Modify Site Preferences');
   }
   
-  function HandlesEvents () {
-    return false;
-  }
-
-  function InstallPostMessage() {
-    return $this->Lang('postinstall');
-  }
-
-  function UninstallPostMessage() {
-    return $this->Lang('postuninstall');
-  }
-
-  function GetEventHelp( $eventname ) {
-    return $this->Lang('help_event_'.$eventname);
-  }
 } // end of class
 
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
