@@ -39,6 +39,7 @@ if( !isset($gCms) ) exit;
 //
 // setup
 //
+debug_to_log('in CGJobMgr Process action');
 
 $handlers = ob_list_handlers(); 
 for ($cnt = 0; $cnt < sizeof($handlers); $cnt++) { ob_end_clean(); }
@@ -137,9 +138,13 @@ try
 
   // did we get a job?
   if( !$tmp ) {
+    debug_to_log($db->sql);
+    debug_to_log('CGJobMgr got no job');
     return;
   }
 
+  debug_to_log('CGJobMgr got job '.$tmp);
+
   // we have a job to play with.
   // get the job
   $job = cgjobmgr_job::load_from_data($tmp);
@@ -157,6 +162,7 @@ try
   // set some stuff into the job manager... maybe time limits, notification rules, etc.
   $jobmgr->set_value('iterative_slack',$iterative_slack);
   $jobmgr->set_value('max_time',$job_timeout);
+  $jobmgr->set_value('max_autotask_iterations',$this->GetPreference('max_autotask_iterations',10));
 
   // then do the work.
   $status = $jobmgr->process();
